@@ -1,2 +1,5 @@
 from pyshex.prefixlib import PrefixLibrary, standard_prefixes, known_prefixes
 from pyshex.shex_evaluator import ShExEvaluator
+
+import rdflib_shim
+shim_installed = rdflib_shim.RDFLIB_SHIM
