@@ -6,12 +6,14 @@ from CFGraph import CFGraph
 from ShExJSG import ShExJ, ShExC
 from rdflib import Graph, URIRef, RDF
 from rdflib.util import guess_format
-from sparql_slurper import SlurpyGraph
+from sparqlslurper import QueryResultPrinter
 
+from pyshex import PrefixLibrary
 from pyshex.shape_expressions_language.p5_2_validation_definition import isValid
 from pyshex.shape_expressions_language.p5_context import Context
 from pyshex.shapemap_structure_and_language.p3_shapemap_structure import FixedShapeMap, ShapeAssociation, START, \
     START_TYPE
+from pyshex.user_agent import UserAgent, SlurpyGraphWithAgent
 from pyshex.utils.schema_loader import SchemaLoader
 from pyshex.utils.sparql_query import SPARQLQuery
 
@@ -78,6 +80,7 @@ class ShExEvaluator:
         :param over_slurp: Controls whether SPARQL slurper does exact or over slurps
         :param output_sink: Function for accepting evaluation results and returns whether to keep evaluating
         """
+        self.pfx: PrefixLibrary = None
         self.rdf_format = rdf_format
         self.g = None
         self.rdf = rdf
@@ -92,6 +95,7 @@ class ShExEvaluator:
         self.output_sink = output_sink
         self.nerrors = 0
         self.nnodes = 0
+        self.eval_result = []
 
     @property
     def rdf(self) -> str:
@@ -134,17 +138,20 @@ class ShExEvaluator:
 
         :param shex:  Schema
         """
+        self.pfx = None
         if shex is not None:
             if isinstance(shex, ShExJ.Schema):
                 self._schema = shex
             else:
                 shext = shex.strip()
+                loader = SchemaLoader()
                 if ('\n' in shex or '\r' in shex) or shext[0] in '#<_: ':
-                    self._schema = SchemaLoader().loads(shex)
+                    self._schema = loader.loads(shex)
                 else:
-                    self._schema = SchemaLoader().load(shex) if isinstance(shex, str) else shex
+                    self._schema = loader.load(shex) if isinstance(shex, str) else shex
                 if self._schema is None:
                     raise ValueError("Unable to parse shex file")
+                self.pfx = PrefixLibrary(loader.schema_text)
 
     @property
     def focus(self) -> Optional[List[URIRef]]:
@@ -202,20 +209,24 @@ class ShExEvaluator:
         else:
             evaluator = self
 
-        rval = []
+        self.eval_result = []
         if evaluator.output_sink is None:
             def sink(e: EvaluationResult) -> bool:
-                rval.append(e)
+                self.eval_result.append(e)
                 return True
             evaluator.output_sink = sink
 
         processing = True
         self.nerrors = 0
         self.nnodes = 0
-        if START in self.start and evaluator._schema.start is None:
+        if START in evaluator.start and evaluator._schema.start is None:
             self.nerrors += 1
             evaluator.output_sink(EvaluationResult(False, None, None, 'START node is not specified'))
-            return rval
+            return self.eval_result
+
+        # Experimental -- xfer all ShEx namespaces to g
+        if self.pfx and evaluator.g is not None:
+            self.pfx.add_bindings_to(evaluator.g)
 
         cntxt = Context(evaluator.g, evaluator._schema)
         cntxt.debug_context.debug = debug if debug is not None else self.debug
@@ -249,7 +260,7 @@ class ShExEvaluator:
                 evaluator.output_sink(EvaluationResult(False, focus, None, "No start node located"))
             if not processing:
                 break
-        return rval
+        return self.eval_result
 
 
 def genargs(prog: Optional[str] = None) -> ArgumentParser:
@@ -268,10 +279,18 @@ def genargs(prog: Optional[str] = None) -> ArgumentParser:
     parser.add_argument("-A", "--allsubjects", help="Evaluate all non-bnode subjects in the graph", action="store_true")
     parser.add_argument("-d", "--debug", action="store_true", help="Add debug output")
     parser.add_argument("-ss", "--slurper", action="store_true", help="Use SPARQL slurper graph")
+    parser.add_argument("-ssg", "--gdbslurper", action="store_true", help="Use GraphDB specific slurper to "
+                                                                          "persistent BNodes")
     parser.add_argument("-cf", "--flattener", action="store_true", help="Use RDF Collections flattener graph")
     parser.add_argument("-sq", "--sparql", help="SPARQL query to generate focus nodes")
     parser.add_argument("-se", "--stoponerror", help="Stop on an error", action="store_true")
     parser.add_argument("--stopafter", help="Stop after N nodes", type=int)
+    parser.add_argument("-ps", "--printsparql", help="Print SPARQL queries as they are executed", action="store_true")
+    parser.add_argument("-pr", "--printsparqlresults", help="Print SPARQL query and results", action="store_true")
+    parser.add_argument("-gn", "--graphname", help="Specific SPARQL graph to query - use '' for any named graph")
+    parser.add_argument("-pb", "--persistbnodes", help="Treat BNodes as persistent in SPARQL endpoint",
+                        action="store_true"),
+    parser.add_argument("--useragent", help='Use this user agent in the SPARQL Queries (Default: "' + UserAgent + '")')
     return parser
 
 
@@ -279,24 +298,41 @@ def evaluate_cli(argv: Optional[Union[str, List[str]]] = None, prog: Optional[st
     if isinstance(argv, str):
         argv = argv.split()
     opts = genargs(prog).parse_args(argv if argv is not None else sys.argv[1:])
-    if opts.sparql:
+    if opts.sparql or opts.gdbslurper:
         opts.slurper = True
     if opts.slurper and opts.flattener:
-        print("Error: Cannot combine slurper and flattener graphs")
+        print("Error: Cannot combine slurper and flattener graphs", file=sys.stderr)
         return 2
+    if not opts.sparql and not opts.slurper and \
+            (opts.printsparql or opts.printsparqlresults or opts.graphname is not None or opts.persistbnodes):
+        print("Error: printsparql, pringsparqlresults, graphname and persistbnodes are SPARQL only",
+              file=sys.stderr)
     if not opts.format:
         opts.format = guess_format(opts.rdf)
     if not opts.format:
-        print('Error: Cannot determine RDF format from file name - use "--format" option')
+        print('Error: Cannot determine RDF format from file name - use "--format" option', file=sys.stderr)
         return 3
-    g = SlurpyGraph(opts.rdf) if opts.slurper else CFGraph() if opts.flattener else Graph()
-    if not opts.slurper:
+    if opts.slurper or opts.gdbslurper:
+        g = SlurpyGraphWithAgent(opts.rdf, agent=opts.useragent, gdb_slurper=opts.gdbslurper)
+        if opts.printsparql:
+            g.debug_slurps = True
+        if opts.printsparqlresults:
+            g.debug_slurps = True
+            g.add_result_hook(QueryResultPrinter)
+        if opts.graphname is not None:
+            g.graph_name = opts.graphname
+        if opts.persistbnodes:
+            g.persistent_bnodes = True
+    else:
+        g = CFGraph() if opts.flattener else Graph()
         if '\n' in opts.rdf or '\r' in opts.rdf:
             g.parse(data=opts.rdf, format=opts.format)
         else:
-            g.load(opts.rdf, format=opts.format)
+            g.parse(opts.rdf, format=opts.format)
+
     if not (opts.focus or opts.allsubjects or opts.sparql):
-        print('Error: You must specify one or more graph focus nodes, supply a SPARQL query, or use the "-A" option')
+        print('Error: You must specify one or more graph focus nodes, supply a SPARQL query, or use the "-A" option',
+              file=sys.stderr)
         return 4
 
     start = []
@@ -314,7 +350,8 @@ def evaluate_cli(argv: Optional[Union[str, List[str]]] = None, prog: Optional[st
             opts.focus = []
         elif not isinstance(opts.focus, list):
             opts.focus = [opts.focus]
-        opts.focus += list(SPARQLQuery(opts.rdf, opts.sparql, ).focus_nodes())
+        opts.focus += list(SPARQLQuery(opts.rdf, opts.sparql, print_query=opts.printsparql,
+                                       print_results=opts.printsparqlresults, user_agent=opts.useragent).focus_nodes())
 
     def result_sink(rslt: EvaluationResult) -> bool:
         if not rslt.result:
