@@ -2,9 +2,11 @@ import unittest
 
 import os
 
+from tests import SKIP_EXTERNAL_URLS, SKIP_EXTERNAL_URLS_MSG
 from tests.utils.wikidata_utils import WikiDataTestCase
 
 
+@unittest.skipIf(SKIP_EXTERNAL_URLS, SKIP_EXTERNAL_URLS_MSG)
 class ReactomeTestCase(WikiDataTestCase):
     # This will change over time - expected values for the first 8 results
     # Note: This test has never been run past 1
@@ -22,6 +24,5 @@ class ReactomeTestCase(WikiDataTestCase):
                                                                             self.expected_results)))
 
 
-
 if __name__ == '__main__':
     unittest.main()
